DeliveryWindow : The time range within which a Scheduled Delivery fulfillment order should be delivered.
Fields
start_date: Stringend_date: StringImplementations
sourceimpl DeliveryWindow
impl DeliveryWindow
sourcepub fn new(start_date: String, end_date: String) -> DeliveryWindow
pub fn new(start_date: String, end_date: String) -> DeliveryWindow
The time range within which a Scheduled Delivery fulfillment order should be delivered.